@@ -199,12 +199,20 @@ while loop == 1: # This creates an infinite loop
       break
 print '==================='
 print docker_ip
-data = {'cmd': [['connect_secure',{'ip':docker_ip,'login':'ec2-user','identityfile':'fullauto.pem'}]]}
+data = {'cmd': [['connect_secure',{'ip':docker_ip,'login':'ec2-user','identityfile':'fullauto.pem','noretry':'1'}]]}
 time.sleep( 1 )
 print "SENDING"
 #data = {'cmd': [['cmd','pwd']]}
-headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
-result = json.loads(content)
-result = json.loads(result['result'])
-print result
+while loop == 1: # This creates an infinite loop
+   print "GOING FOR CONNECT"
+   headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
+   result = json.loads(content)
+   result = json.loads(result['result'])
+   if re.search('Connection timed out|Connection refused',result[0][1]):
+      print result[0][1]
+      time.sleep( 1 )
+      continue
+   else:
+      print result[0][0]
+   break
 
